@@ -72,9 +72,6 @@ if (!window.Picasso.hasOwnProperty("Dialog")) {
         /* Assign max downloads */
         if (-1 !== dialog._link.getMaxDownloads()) {
             inputs.pica_link_max_downloads.val(dialog._link.getMaxDownloads());
-            if (dialog._link.getMaxDownloads() === 0){
-                $('#pica_link_disable_download').trigger('click');
-            }
         }
 
         /* Assign password */
@@ -123,6 +120,17 @@ if (!window.Picasso.hasOwnProperty("Dialog")) {
             inputs.pica_link_disable_download?.closest("div").show()
         }
 
+        (function maybeAutoDisable() {
+            if (dialog._link.getMaxDownloads() === 0) {
+                const file = dialog._link.getFile();
+                const isFile = dialog._link.getFile().is(Picasso.File.Flags.FILE)
+                const isSpecial = isFile && (file.isInline() || file.isImage() || file.isOODocument() || file.isTXT());
+                if (isSpecial) {
+                    $('#pica_link_disable_download').trigger('click');
+                }
+            }
+        })();
+
     };
 
     /**
