@@ -2088,4 +2088,24 @@ if (!window.Picasso.hasOwnProperty("Helper")) {
         });
     };
 
+    Picasso.Helper.isEmptyPool = function () {
+        var pool = Picasso.Helper.xhrPool || {};
+        return Object.keys(pool).length === 0;
+    };
+
+    Picasso.Helper.abortAllPending = function () {
+        var pool = Picasso.Helper.xhrPool || {};
+        var keys = Object.keys(pool);
+
+        keys.forEach(function (key) {
+            var arr = pool[key];
+            if (Array.isArray(arr) && arr.length) {
+                arr.slice().forEach(function (jqXHR) {
+                    try { jqXHR.abort(); } catch (e) {}
+                });
+            }
+            delete pool[key];
+        });
+    };
+
 })();
