@@ -521,8 +521,12 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
             dialog.setOkHandler(function (inputs) {
                 var baseName = inputs.pica_input_text.val();
-                var ext = inputs.pica_input_text.data("original-extension") || "";
-                var newName = baseName + ext;
+                var newName = baseName;
+                if (file.is(Picasso.File.Flags.FILE)) {
+                    baseName = baseName.replace(/\.[^/.]+$/, "");
+                    var ext = inputs.pica_input_text.data("original-extension") || "";
+                    newName = baseName + ext;
+                }
 
                 var cwd = Picasso.get("cwd");
 
@@ -698,10 +702,12 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
         dialog.setOkHandler(function (inputs) {
             var baseName = inputs.pica_input_text.val();
-            var ext = inputs.pica_input_text.data("original-extension") || "";
-            var newName = baseName + ext;
-
-
+            var newName = baseName;
+            if (file.is(Picasso.File.Flags.FILE)) {
+                baseName = baseName.replace(/\.[^/.]+$/, "");
+                var ext = inputs.pica_input_text.data("original-extension") || "";
+                newName = baseName + ext;
+            }
             file.renameFileLink(newName,
 
                     /* Success */
@@ -741,6 +747,7 @@ if (!window.Picasso.hasOwnProperty("Files")) {
                                 Picasso.Notification.show(
                                         Picasso.Lang.get("notification_error_duplicate", name),
                                         "warning");
+                                break
 
                             case 400:
                                 /* Falls through */
