@@ -12,11 +12,29 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 /* Private scope */
 (function () {
 
+    function showFilesSpinner() {
+        var $tbody = $("#files_files_table tbody");
+        var cols = $("#files_files_table thead tr:last th:visible").length || 6;
+
+        $tbody.empty().append(
+            $("<tr>", { class: "pica-not-striped" }).append(
+                $("<td>", { class: "text-center", colspan: cols }).append(
+                    $("<span>", { class: "pica-glyph pica-spinner glyphicons glyphicons-repeat" })
+                )
+            )
+        );
+    }
+
+
     window.onpopstate = (event) => {
         var state = event.state;
         if (state) {
             var update = null;
             var file = new Picasso.File(state);
+
+            showFilesSpinner();
+
+
             if ($(".pica-crumb").eq(-2).find("span").length > 0 &&  $(".pica-crumb").eq(-2).find("span").text() === file.getName()) {
                 update =  function (){
                     $(".pica-crumb").last().remove();
@@ -870,6 +888,9 @@ if (!window.Picasso.hasOwnProperty("Files")) {
                 Picasso.Notification.show(Picasso.Lang.get("notification_error_access_blocked"), "warning")
                 return;
             }
+
+            showFilesSpinner();
+
             Picasso.Files.fetch(file, false,
 
                 /* Success */
@@ -1412,6 +1433,8 @@ if (!window.Picasso.hasOwnProperty("Files")) {
             file = new Picasso.File(file);
         }
 
+        showFilesSpinner();
+
         Picasso.Files.fetch(file);
 
         /* Clear search field */
@@ -1560,6 +1583,19 @@ if (!window.Picasso.hasOwnProperty("Files")) {
             }
         });
 
+        dialog.setValidateFunction(function (inputs) {
+            var documentName = inputs.pica_input_text.val();
+
+            var disallowedCharactersRegex = /[\\\/:\*\?„<>]/;
+
+            if (disallowedCharactersRegex.test(documentName)) {
+                Picasso.Notification.show(
+                    Picasso.Lang.get("notification_error_invalid_chars"), "warning");
+                return false;
+            }
+            return true;
+        });
+
         dialog.show();
     };
 
@@ -1635,7 +1671,7 @@ if (!window.Picasso.hasOwnProperty("Files")) {
         dialog.setValidateFunction(function (inputs) {
             var documentName = inputs.pica_input_text.val();
 
-            var disallowedCharactersRegex = /[*,?\/:<>\|"]|\.{2,}/;
+            var disallowedCharactersRegex = /[\\\/:\*\?„<>]/;
 
             if (disallowedCharactersRegex.test(documentName)) {
                 Picasso.Notification.show(
@@ -2061,15 +2097,7 @@ if (!window.Picasso.hasOwnProperty("Files")) {
         } else if (0 === nmatches && 0 === filterString.length) {
             VMTABLE.getTable().clear();
             VMTABLE.getTable().hideEmptyMessage();
-            var tr = $("<tr>", {
-                class: "pica-not-striped"
-            });
-
-            var td = $("<td>", {class: "text-center", colspan: "6"});
-            var span = $("<span>", {class: "pica-glyph pica-spinner glyphicons glyphicons-repeat"});
-            td.append(span);
-            tr.append(td);
-            $("#files_files_table").append(tr);
+            showFilesSpinner();
             Picasso.Files.fetch(cwd)
         } else {
             VMTABLE.getTable().hideEmptyMessage();
@@ -2273,10 +2301,10 @@ if (!window.Picasso.hasOwnProperty("Files")) {
 
                 if (file.getModifiedBy() || file.getModifiedByAccount()) {
                     let modifiedBy = file.getModifiedByAccount() ? file.getModifiedByAccount() : file.getModifiedBy() ? file.getModifiedBy() : ""
+                    let modifiedOn = file.getModifiedOn() ? Picasso.Lang.get("string_on", file.getModifiedOn()) : "";
                     var span = $("<span>", {
                         text: modifiedBy,
-                        title: Picasso.Lang.get("string_on",
-                            file.getModifiedOn()),
+                        title: modifiedOn,
                         "data-tooltip": "tooltip_share",
                         "data-placement": "bottom"
                     });
@@ -2638,6 +2666,7 @@ if (!window.Picasso.hasOwnProperty("Files")) {
         /* Reset page */
         if (true !== append) {
             PAGE = 1;
+            showFilesSpinner();
         }
 
         /* Update file list */
