@@ -207,9 +207,11 @@ if (!window.Picasso.hasOwnProperty("Pricing")) {
             "/wapi/pricing",
             { action: "createCheckout", priceId: priceId },
             // onSuccess
-            function(json, status) {
+            function (json, status) {
                 if (json && json.sessionUrl) {
                     window.location = json.sessionUrl;
+                } else if (json && json.redirectUrl) {
+                    window.location.href = json.redirectUrl;
                 } else {
                     console.error("No sessionUrl from createCheckout", json);
                 }
