@@ -63,6 +63,8 @@ if (!window.Picasso.hasOwnProperty("Versions")) {
         e.preventDefault();
         e.stopPropagation();
 
+        $("[data-toggle='tooltip']").tooltip("hide");
+
         var file = new Picasso.File($(this).data("serial"));
 
         /* Check type */
@@ -288,6 +290,7 @@ if (!window.Picasso.hasOwnProperty("Versions")) {
             text: file.getName(),
             "data-serial": file.serialize()
         });
+        Picasso.Helper.addTooltip(a,file.getName());
 
         a.click(handleClickName);
 
