@@ -147,6 +147,9 @@ if (!window.hasOwnProperty("Picasso")) {
                         imageEmbedded: "data:image/gif;base64,R0lGODlhAQABAAD/ACwAAAAAAQABAAACADs=",
                         url: "https://powerfolder.com"
                     },
+                    features: {
+                        featuresTips: false,
+                    }
                 },
                 events: {
 
@@ -179,8 +182,16 @@ if (!window.hasOwnProperty("Picasso")) {
                 config.token = res.token;
             }
             new DocsAPI.DocEditor("editor", config);
-        }, function () {
-            Picasso.Notification.show(Picasso.Lang.get("notification_jwt_signature_failed"), "danger");
+        }, function (e,status) {
+            switch (status) {
+                case 400:
+                    Picasso.Notification.show(Picasso.Lang.get("notification_jwt_signature_failed"), "danger");
+                    break;
+                default:
+                    Picasso.Notification.show(Picasso.Lang.get("notification_error"), "danger");
+                    break;
+            }
+
         });
 
         /* Start touch timer */
