@@ -802,6 +802,9 @@ if (!window.hasOwnProperty("Picasso")) {
                                                 pageNum, pageSize,
                                                 deletedOnly, query ,recursive)
     {
+
+        $("#files_files_table tbody .pica-spinner").show();
+
         /* Handle types */
         if (this.is(Picasso.File.Flags.FOLDER|Picasso.File.Flags.DIRECTORY)) {
             var url = Picasso.Helper.joinPaths([
@@ -823,10 +826,9 @@ if (!window.hasOwnProperty("Picasso")) {
                 data.query = query;
             }
 
-            //check if there is already a calls on the page and cancel them
-            if (Picasso.Helper.xhrPool[url] && Picasso.Helper.xhrPool[url].length > 0) {
-                Picasso.Helper.abortAll(url)
-                $("#files_files_table tbody .pica-spinner").hide();
+            // Check if there is already a calls on the page and cancel them
+            if (!Picasso.Helper.isEmptyPool()) {
+                Picasso.Helper.abortAllPending();
             }
 
             if (recursive) {
@@ -1168,6 +1170,9 @@ if (!window.hasOwnProperty("Picasso")) {
 
     Picasso.File.getAll = function (onSuccess, onError, pageNum, pageSize, deletedOnly, query, filter)
     {
+
+        $("#files_files_table tbody .pica-spinner").show();
+
         var url = "/wapi/folders";
         var data = {
             action: "getAll",
@@ -1190,9 +1195,8 @@ if (!window.hasOwnProperty("Picasso")) {
         }
 
         //check if there is already a calls on the page and cancel them
-        if (Picasso.Helper.xhrPool[url] && Picasso.Helper.xhrPool[url].length > 0) {
-            Picasso.Helper.abortAll(url)
-            $("#files_files_table tbody .pica-spinner").hide();
+        if (!Picasso.Helper.isEmptyPool()) {
+            Picasso.Helper.abortAllPending()
         }
 
         /* Fire ajax call */
